summaryrefslogtreecommitdiff
path: root/src/file.h
diff options
context:
space:
mode:
authorjakob <jakob@memeware.net>2017-01-12 17:09:17 -0500
committerjakob <jakob@memeware.net>2017-01-12 17:09:17 -0500
commit43e539561a4ea95274468b78735555d6e89fdfd9 (patch)
tree4a005aed01dc34c40b4fe5657d2b155ea4231e85 /src/file.h
parent350b126eef468c7c8d66c72100d8a3c76e9afec1 (diff)
Finished implementation of file decryption. There are still many memory corruption bugs and a segfault is not uncommon.
Diffstat (limited to 'src/file.h')
-rw-r--r--src/file.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/file.h b/src/file.h
index dc96154..046cd48 100644
--- a/src/file.h
+++ b/src/file.h
@@ -29,14 +29,14 @@ typedef struct {
/* Node in a linked list of file entries to write to disk. */
typedef struct file_node {
- int compressed; /* Whether or not the archive is compressed. */
+ int encrypted; /* Whether or not the entry is encrypted. */
+ int compressed; /* Whether or not the entry is compressed. */
uint32_t key; /* Key associated with matching eliF entry. */
- uint64_t compressed_size; /* Size of compressed chunk. */
- uint64_t decompressed_size; /* Size of decompressed data. */
+ uint64_t file_size; /* Total size of decompressed file. */
uint64_t segment_count; /* Number of segments in File entry. */
segment **segments; /* Data segments associated with the entry. */
struct file_node *next; /* Pointer to the next node. */
} file_node;
/* Creates a file node by parsing a file entry. */
-file_node *read_file_node(memory_stream *data_stream, Bytef *section_end);
+file_node *read_file_entry(memory_stream *data_stream, Bytef *section_end);